@@ -33,10 +33,6 @@
 #include <string.h>
 #include <ctype.h>
 
-#ifdef HAVE_ALLOCA_H
-#include <alloca.h>
-#endif
-
 #include "gmime-part.h"
 #include "gmime-utils.h"
 #include "gmime-stream-mem.h"
@@ -134,7 +130,7 @@ g_mime_part_finalize (GObject *object)
 	g_free (mime_part->content_md5);
 	
 	if (mime_part->content)
-		g_mime_data_wrapper_destroy (mime_part->content);
+		g_object_unref (mime_part->content);
 	
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
@@ -168,10 +164,10 @@ static char *headers[] = {
 static void
 set_disposition (GMimePart *mime_part, const char *disposition)
 {
-	if (!mime_part->disposition)
-		mime_part->disposition = g_mime_disposition_new (NULL);
+	if (mime_part->disposition)
+		g_mime_disposition_destroy (mime_part->disposition);
 	
-	g_mime_disposition_set (mime_part->disposition, disposition);
+	mime_part->disposition = g_mime_disposition_new (disposition);
 }
 
 static gboolean
@@ -182,13 +178,13 @@ process_header (GMimeObject *object, const char *header, const char *value)
 	int i;
 	
 	for (i = 0; headers[i]; i++) {
-		if (!strcasecmp (headers[i], header))
+		if (!g_strcasecmp (headers[i], header))
 			break;
 	}
 	
 	switch (i) {
 	case HEADER_CONTENT_TRANSFER_ENCODING:
-		text = alloca (strlen (value) + 1);
+		text = g_alloca (strlen (value) + 1);
 		strcpy (text, value);
 		g_strstrip (text);
 		mime_part->encoding = g_mime_part_encoding_from_string (text);
@@ -223,7 +219,7 @@ mime_part_add_header (GMimeObject *object, const char *header, const char *value
 	/* Make sure that the header is a Content-* header, else it
            doesn't belong on a mime part */
 	
-	if (!strncasecmp ("Content-", header, 8)) {
+	if (!g_strncasecmp ("Content-", header, 8)) {
 		if (process_header (object, header, value))
 			g_mime_header_add (object->headers, header, value);
 		else
@@ -237,7 +233,7 @@ mime_part_set_header (GMimeObject *object, const char *header, const char *value
 	/* Make sure that the header is a Content-* header, else it
            doesn't belong on a mime part */
 	
-	if (!strncasecmp ("Content-", header, 8)) {
+	if (!g_strncasecmp ("Content-", header, 8)) {
 		if (process_header (object, header, value))
 			g_mime_header_set (object->headers, header, value);
 		else
@@ -251,7 +247,7 @@ mime_part_get_header (GMimeObject *object, const char *header)
 	/* Make sure that the header is a Content-* header, else it
            doesn't belong on a mime part */
 	
-	if (!strncasecmp ("Content-", header, 8))
+	if (!g_strncasecmp ("Content-", header, 8))
 		return GMIME_OBJECT_CLASS (parent_class)->get_header (object, header);
 	else
 		return NULL;
@@ -263,7 +259,7 @@ mime_part_remove_header (GMimeObject *object, const char *header)
 	/* Make sure that the header is a Content-* header, else it
            doesn't belong on a mime part */
 	
-	if (!strncasecmp ("Content-", header, 8))
+	if (!g_strncasecmp ("Content-", header, 8))
 		return GMIME_OBJECT_CLASS (parent_class)->remove_header (object, header);
 }
 
@@ -1135,8 +1131,11 @@ g_mime_part_set_content_object (GMimePart *mime_part, GMimeDataWrapper *content)
 {
 	g_return_if_fail (GMIME_IS_PART (mime_part));
 	
+	if (content)
+		g_object_ref (content);
+	
 	if (mime_part->content)
-		g_mime_data_wrapper_destroy (mime_part->content);
+		g_object_unref (mime_part->content);
 	
 	mime_part->content = content;
 }
@@ -1151,11 +1150,14 @@ g_mime_part_set_content_object (GMimePart *mime_part, GMimeDataWrapper *content)
  *
  * Returns the data-wrapper for the mime part's contents.
  **/
-const GMimeDataWrapper *
+GMimeDataWrapper *
 g_mime_part_get_content_object (const GMimePart *mime_part)
 {
 	g_return_val_if_fail (GMIME_IS_PART (mime_part), NULL);
 	
+	if (mime_part->content)
+		g_object_ref (mime_part->content);
+	
 	return mime_part->content;
 }
 
