@@ -32,10 +32,6 @@
 #include <ctype.h>
 #include <errno.h>
 
-#ifdef HAVE_ALLOCA_H
-#include <alloca.h>
-#endif
-
 #include "gmime-utils.h"
 #include "gmime-table-private.h"
 #include "gmime-part.h"
@@ -187,7 +183,11 @@ g_mime_utils_header_format_date (time_t time, int offset)
 	
 	time += ((offset / 100) * (60 * 60)) + (offset % 100) * 60;
 	
+#ifdef HAVE_GMTIME_R
+	gmtime_r (&time, &tm);
+#else
 	memcpy (&tm, gmtime (&time), sizeof (tm));
+#endif
 	
 	return g_strdup_printf ("%s, %02d %s %04d %02d:%02d:%02d %+05d",
 				tm_days[tm.tm_wday], tm.tm_mday,
@@ -313,7 +313,7 @@ get_wday (const unsigned char *in, unsigned int inlen)
 		return -1;
 	
 	for (wday = 0; wday < 7; wday++)
-		if (!strncasecmp (in, tm_days[wday], 3))
+		if (!g_strncasecmp (in, tm_days[wday], 3))
 			return wday;
 	
 	return -1;  /* unknown week day */
@@ -345,7 +345,7 @@ get_month (const unsigned char *in, unsigned int inlen)
 		return -1;
 	
 	for (i = 0; i < 12; i++)
-		if (!strncasecmp (in, tm_months[i], 3))
+		if (!g_strncasecmp (in, tm_months[i], 3))
 			return i;
 	
 	return -1;  /* unknown month */
@@ -1035,13 +1035,13 @@ rfc2047_decode_word (const unsigned char *in, size_t inlen)
 		case 'B':
 		case 'b':
 			inptr += 2;
-			decoded = alloca (inend - inptr);
+			decoded = g_alloca (inend - inptr);
 			declen = g_mime_utils_base64_decode_step (inptr, inend - inptr, decoded, &state, &save);
 			break;
 		case 'Q':
 		case 'q':
 			inptr += 2;
-			decoded = alloca (inend - inptr);
+			decoded = g_alloca (inend - inptr);
 			declen = quoted_decode (inptr, inend - inptr, decoded);
 			
 			if (declen == -1) {
@@ -1055,7 +1055,7 @@ rfc2047_decode_word (const unsigned char *in, size_t inlen)
 		}
 		
 		len = (inptr - 3) - (in + 2);
-		charenc = alloca (len + 1);
+		charenc = g_alloca (len + 1);
 		memcpy (charenc, in + 2, len);
 		charenc[len] = '\0';
 		charset = charenc;
@@ -1073,7 +1073,7 @@ rfc2047_decode_word (const unsigned char *in, size_t inlen)
 			*p = '\0';
 		
 		/* slight optimization */
-		if (!strcasecmp (charset, "UTF-8"))
+		if (!g_strcasecmp (charset, "UTF-8"))
 			return g_strndup (decoded, declen);
 		
 		cd = g_mime_iconv_open ("UTF-8", charset);
@@ -1259,7 +1259,7 @@ rfc2047_encode_word (GString *string, const unsigned char *word, size_t len,
 	char encoding;
 	
 	
-	if (strcasecmp (charset, "UTF-8") != 0)
+	if (g_strcasecmp (charset, "UTF-8") != 0)
 		cd = g_mime_iconv_open (charset, "UTF-8");
 	
 	if (cd != (iconv_t) -1) {
@@ -1277,7 +1277,7 @@ rfc2047_encode_word (GString *string, const unsigned char *word, size_t len,
 	switch (g_mime_utils_best_encoding (word, len)) {
 	case GMIME_PART_ENCODING_BASE64:
 		enclen = BASE64_ENCODE_LEN (len);
-		encoded = alloca (enclen);
+		encoded = g_alloca (enclen);
 		
 		encoding = 'b';
 		
@@ -1292,7 +1292,7 @@ rfc2047_encode_word (GString *string, const unsigned char *word, size_t len,
 		break;
 	case GMIME_PART_ENCODING_QUOTEDPRINTABLE:
 		enclen = QP_ENCODE_LEN (len);
-		encoded = alloca (enclen);
+		encoded = g_alloca (enclen);
 		
 		encoding = 'q';
 		
